@@ -136,7 +136,7 @@ var Options = (new function($)
 		config.values = serverValues;
 
 		readWebSettings(config);
-		
+
 		var serverConfig = readConfigTemplate(serverTemplateData[0].Template, undefined, HIDDEN_SECTIONS, '', '');
 		mergeValues(serverConfig.sections, serverValues);
 		config.push(serverConfig);
@@ -156,6 +156,7 @@ var Options = (new function($)
 			scriptConfig.scan = serverTemplateData[i].ScanScript;
 			scriptConfig.queue = serverTemplateData[i].QueueScript;
 			scriptConfig.scheduler = serverTemplateData[i].SchedulerScript;
+			scriptConfig.defscheduler = serverTemplateData[i].TaskTime !== '';
 			scriptConfig.feed = serverTemplateData[i].FeedScript;
 			mergeValues(scriptConfig.sections, serverValues);
 			config.push(scriptConfig);
@@ -164,12 +165,12 @@ var Options = (new function($)
 		serverValues = null;
 		loadComplete(config);
 	}
-	
+
 	function readWebSettings(config)
 	{
 		var webTemplate = '### WEB-INTERFACE ###\n\n';
 		var webValues = [];
-		
+
 		for (var optname in UISettings.description)
 		{
 			var descript = UISettings.description[optname];
@@ -177,13 +178,13 @@ var Options = (new function($)
 			optname = optname[0].toUpperCase() + optname.substring(1);
 			if (value === true) value = 'yes';
 			if (value === false) value = 'no';
-			
+
 			descript = descript.replace(/\n/g, '\n# ').replace(/\n# \n/g, '\n#\n');
 			webTemplate += '# ' + descript + '\n' + optname + '=' + value + '\n\n';
-			
+
 			webValues.push({Name: optname, Value: value.toString()});
 		}
-		
+
 		var webConfig = readConfigTemplate(webTemplate, undefined, '', '', '');
 		mergeValues(webConfig.sections, webValues);
 		config.push(webConfig);
@@ -445,7 +446,7 @@ var Options = (new function($)
 
 		for (var i=1; i < data.length; i++)
 		{
-			if (data[i].PostScript)
+			if (data[i].PostScript || data[i].QueueScript)
 			{
 				var scriptName = data[i].Name;
 				var sectionId = (scriptName + ':').replace(/ |\/|[\.|$|\:|\*]/g, '_');
@@ -455,7 +456,7 @@ var Options = (new function($)
 				option.caption = option.caption.replace(/\\/, ' \\ ').replace(/\//, ' / ');
 
 				option.defvalue = 'no';
-				option.description = (data[i].Template.trim().split('\n')[0].substr(1, 1000).trim() || 'Post-processing script ' + scriptName + '.');
+				option.description = (data[i].Template.trim().split('\n')[0].substr(1, 1000).trim() || 'Extension script ' + scriptName + '.');
 				option.value = null;
 				option.sectionId = sectionId;
 				option.select = ['yes', 'no'];
@@ -667,6 +668,15 @@ var Config = (new function($)
 		return null;
 	}
 
+	this.processShortcut = function(key)
+	{
+		switch (key)
+		{
+			case 'Shift+F': $('#ConfigTable_filter').focus(); return true;
+			case 'Shift+C': $('#ConfigTable_clearfilter').click(); return true;
+		}
+	}
+
 	/*** GENERATE HTML PAGE *****************************************************************/
 
 	function buildOptionsContent(section, extensionsec)
@@ -685,7 +695,7 @@ var Config = (new function($)
 				// option's content is hidden content anyway (***)
 				break;
 			}
-			
+
 			var option = section.options[i];
 			if (!option.template)
 			{
@@ -807,13 +817,20 @@ var Config = (new function($)
 				'<span class="add-on">'+ option.select[0] +'</span>'+
 				'</div>';
 		}
-		else if (option.name.toLowerCase() === 'serverpassword')
+		else if (option.name.toLowerCase().indexOf('password') > -1 &&
+                                option.name.toLowerCase() !== '*unpack:password')
 		{
 			option.type = 'password';
-			html += '<input type="password" id="' + option.formId + '" value="' + Util.textToAttr(value) + '" class="editsmall">';
+			html += '<div class="password-field input-append">' +
+                                '<input type="password" id="' + option.formId + '" value="' + Util.textToAttr(value) + '" class="editsmall">'+
+                                '<span class="add-on">'+
+                                '<label class="checkbox">'+
+                                '<input type="checkbox" onclick="Config.togglePassword(this, \'' + option.formId + '\')" /> Show'+
+                                '</label>'+
+                                '</span>'+
+                                '</div>';
 		}
 		else if (option.name.toLowerCase().indexOf('username') > -1 ||
-				option.name.toLowerCase().indexOf('password') > -1 ||
 				(option.name.indexOf('IP') > -1 && option.name.toLowerCase() !== 'authorizedip'))
 		{
 			option.type = 'text';
@@ -968,7 +985,7 @@ var Config = (new function($)
 				$ConfigNav.append(html);
 			}
 		}
-		
+
 		notifyChanges();
 
 		$ConfigNav.append('<li class="divider hide ConfigSearch"></li>');
@@ -1052,25 +1069,21 @@ var Config = (new function($)
 			{
 				var option = section.options[k];
 				var optname = option.name.toLowerCase();
-				if (optname.indexOf('scriptorder') > -1)
+				if (optname === 'scriptorder')
 				{
 					option.editor = { caption: 'Reorder', click: 'Config.editScriptOrder' };
 				}
-				if (optname.indexOf('postscript') > -1)
+				if (optname === 'extensions')
 				{
-					option.editor = { caption: 'Choose', click: 'Config.editPostScript' };
+					option.editor = { caption: 'Choose', click: 'Config.editExtensions' };
 				}
-				if (optname.indexOf('scanscript') > -1)
+				if (optname.indexOf('category') > -1 && optname.indexOf('.extensions') > -1)
 				{
-					option.editor = { caption: 'Choose', click: 'Config.editScanScript' };
+					option.editor = { caption: 'Choose', click: 'Config.editCategoryExtensions' };
 				}
-				if (optname.indexOf('queuescript') > -1)
+				if (optname.indexOf('feed') > -1 && optname.indexOf('.extensions') > -1)
 				{
-					option.editor = { caption: 'Choose', click: 'Config.editQueueScript' };
-				}
-				if (optname.indexOf('feedscript') > -1)
-				{
-					option.editor = { caption: 'Choose', click: 'Config.editFeedScript' };
+					option.editor = { caption: 'Choose', click: 'Config.editFeedExtensions' };
 				}
 				if (optname.indexOf('task') > -1 && optname.indexOf('.param') > -1)
 				{
@@ -1107,7 +1120,7 @@ var Config = (new function($)
 			}
 		}
 	}
-	
+
 	function scrollOptionIntoView(optFormId)
 	{
 		var option = findOptionById(optFormId);
@@ -1156,6 +1169,12 @@ var Config = (new function($)
 		$('.btn@[value=' + value + ']', control).addClass('btn-primary');
 	}
 
+        this.togglePassword = function(control, target)
+        {
+                var checked = $(control).is(':checked');
+                $('#'+target).prop('type', checked ? 'text' : 'password');
+        }
+
 	/*** CHANGE/ADD/REMOVE OPTIONS *************************************************************/
 
 	function navClick(event)
@@ -1314,7 +1333,7 @@ var Config = (new function($)
 			}
 		}
 	}
-	
+
 	this.addSet = function(setname, sectionId)
 	{
 		// find section
@@ -1372,7 +1391,7 @@ var Config = (new function($)
 				option.onchange(option);
 			}
 		}
-		
+
 		div.slideDown('normal', function()
 		{
 			var opts = div.children();
@@ -1390,12 +1409,12 @@ var Config = (new function($)
 		// swap options in two sets
 		var opts1 = $('.' + sectionId + '.multiid' + (direction === 'down' ? id1 : id2), $ConfigData);
 		var opts2 = $('.' + sectionId + '.multiid' + (direction === 'down' ? id2 : id1), $ConfigData);
-		
+
 		if (opts1.length === 0 || opts2.length === 0)
 		{
 			return;
 		}
-		
+
 		opts1.first().before(opts2);
 
 		// reformat remaining sets (captions, input IDs, etc.)
@@ -1428,28 +1447,22 @@ var Config = (new function($)
 		ScriptListDialog.showModal(option, config, null);
 	}
 
-	this.editPostScript = function(optFormId)
+	this.editExtensions = function(optFormId)
 	{
 		var option = findOptionById(optFormId);
-		ScriptListDialog.showModal(option, config, 'post');
+		ScriptListDialog.showModal(option, config, ['post', 'scan', 'queue', 'defscheduler']);
 	}
 
-	this.editScanScript = function(optFormId)
+	this.editCategoryExtensions = function(optFormId)
 	{
 		var option = findOptionById(optFormId);
-		ScriptListDialog.showModal(option, config, 'scan');
+		ScriptListDialog.showModal(option, config, ['post', 'scan', 'queue']);
 	}
 
-	this.editQueueScript = function(optFormId)
+	this.editFeedExtensions = function(optFormId)
 	{
 		var option = findOptionById(optFormId);
-		ScriptListDialog.showModal(option, config, 'queue');
-	}
-
-	this.editFeedScript = function(optFormId)
-	{
-		var option = findOptionById(optFormId);
-		ScriptListDialog.showModal(option, config, 'feed');
+		ScriptListDialog.showModal(option, config, ['feed']);
 	}
 
 	this.editSchedulerScript = function(optFormId)
@@ -1461,7 +1474,7 @@ var Config = (new function($)
 			alert('This button is to choose scheduler scripts when option TaskX.Command is set to "Script".');
 			return;
 		}
-		ScriptListDialog.showModal(option, config, 'scheduler');
+		ScriptListDialog.showModal(option, config, ['scheduler']);
 	}
 
 	this.schedulerCommandChanged = function(option)
@@ -1470,7 +1483,7 @@ var Config = (new function($)
 		var btnId = option.formId.replace(/Command/, 'Param_Editor');
 		Util.show('#' + btnId, command === 'Script');
 	}
-	
+
 	/*** RSS FEEDS ********************************************************************/
 
 	this.editFilter = function(optFormId)
@@ -1486,7 +1499,7 @@ var Config = (new function($)
 			getOptionValue(findOptionByName('Feed' + option.multiid + '.Category')),
 			getOptionValue(findOptionByName('Feed' + option.multiid + '.Priority')),
 			getOptionValue(findOptionByName('Feed' + option.multiid + '.Interval')),
-			getOptionValue(findOptionByName('Feed' + option.multiid + '.FeedScript')),
+			getOptionValue(findOptionByName('Feed' + option.multiid + '.Extensions')),
 			function(filter)
 				{
 					var control = $('#' + option.formId);
@@ -1506,13 +1519,13 @@ var Config = (new function($)
 			getOptionValue(findOptionByName('Feed' + multiid + '.Category')),
 			getOptionValue(findOptionByName('Feed' + multiid + '.Priority')),
 			getOptionValue(findOptionByName('Feed' + multiid + '.Interval')),
-			getOptionValue(findOptionByName('Feed' + multiid + '.FeedScript')));
+			getOptionValue(findOptionByName('Feed' + multiid + '.Extensions')));
 	}
 
 	/*** TEST SERVER ********************************************************************/
 
 	var connecting = false;
-	
+
 	this.testConnection = function(control, setname, sectionId)
 	{
 		if (connecting)
@@ -1537,7 +1550,7 @@ var Config = (new function($)
 					$('#Notif_Config_TestConnectionProgress').fadeOut(function() {
 						if (errtext == '')
 						{
-							Notification.show('#Notif_Config_TestConnectionOK');
+							PopupNotification.show('#Notif_Config_TestConnectionOK');
 						}
 						else
 						{
@@ -1588,7 +1601,7 @@ var Config = (new function($)
 		}
 	}
 	this.setOptionValue = setOptionValue;
-	
+
 	// Checks if there are obsolete or invalid options
 	function invalidOptionsExist()
 	{
@@ -1662,7 +1675,7 @@ var Config = (new function($)
 
 		if (serverSaveRequest.length === 0 && webSaveRequest.length === 0)
 		{
-			Notification.show('#Notif_Config_Unchanged');
+			PopupNotification.show('#Notif_Config_Unchanged');
 			return;
 		}
 
@@ -1674,7 +1687,7 @@ var Config = (new function($)
 		{
 			saveWebSettings(webSaveRequest);
 		}
-		
+
 		if (serverSaveRequest.length > 0)
 		{
 			$('#Notif_Config_Failed_Filename').text(Options.option('ConfigFile'));
@@ -1706,7 +1719,7 @@ var Config = (new function($)
 		}
 		else
 		{
-			Notification.show('#Notif_Config_Failed');
+			PopupNotification.show('#Notif_Config_Failed');
 		}
 		configSaved = true;
 	}
@@ -1725,7 +1738,7 @@ var Config = (new function($)
 		}
 		UISettings.save();
 	}
-	
+
 	this.canLeaveTab = function(target)
 	{
 		if (!config || prepareSaveRequest(true).length === 0 || configSaved)
@@ -1819,7 +1832,7 @@ var Config = (new function($)
 		$ConfigData.children().hide();
 
 		searcher.compile(filterText);
-		
+
 		var total = 0;
 		var available = 0;
 
@@ -2018,18 +2031,11 @@ var ScriptListDialog = (new function($)
 
 		$ScriptTable.fasttable(
 			{
-				pagerContainer: $('#ScriptListDialog_ScriptTable_pager'),
-				headerCheck: $('#ScriptListDialog_ScriptTable > thead > tr:first-child'),
+				pagerContainer: '#ScriptListDialog_ScriptTable_pager',
 				infoEmpty: 'No scripts found. If you just changed option "ScriptDir", save settings and reload NZBGet.',
 				pageSize: 1000
 			});
 
-		$ScriptTable.on('click', 'tbody div.check',
-			function(event) { $ScriptTable.fasttable('itemCheckClick', this.parentNode.parentNode, event); });
-		$ScriptTable.on('click', 'thead div.check',
-			function() { $ScriptTable.fasttable('titleCheckClick') });
-		$ScriptTable.on('mousedown', Util.disableShiftMouseDown);
-
 		$ScriptListDialog.on('hidden', function()
 		{
 			// cleanup
@@ -2047,13 +2053,13 @@ var ScriptListDialog = (new function($)
 
 		if (orderMode)
 		{
-			$('#ScriptListDialog_Title').text('Reorder scripts');
+			$('#ScriptListDialog_Title').text('Reorder extensions');
 			$('#ScriptListDialog_Instruction').text('Hover mouse over table elements for reorder buttons to appear.');
 		}
 		else
 		{
-			$('#ScriptListDialog_Title').text('Choose scripts');
-			$('#ScriptListDialog_Instruction').html('Select scripts for option <strong>' + option.name + '</strong>.');
+			$('#ScriptListDialog_Title').text('Choose extensions');
+			$('#ScriptListDialog_Instruction').html('Select extension scripts for option <strong>' + option.name + '</strong>.');
 		}
 
 		$ScriptTable.toggleClass('table-hidecheck', orderMode);
@@ -2102,7 +2108,15 @@ var ScriptListDialog = (new function($)
 		for (var i=1; i < config.length; i++)
 		{
 			availableAllScripts.push(config[i].scriptName);
-			if (!kind || config[i][kind])
+			var accept = !kind;
+			if (!accept)
+			{
+				for (var j=0; j < kind.length; j++)
+				{
+					accept = accept || config[i][kind[j]];
+				}
+			}
+			if (accept)
 			{
 				availableScripts.push(config[i].scriptName);
 			}
@@ -2194,7 +2208,7 @@ var ScriptListDialog = (new function($)
 					}
 				}
 			}
-			
+
 			control.val(orderList.join(', '));
 		}
 
@@ -2497,17 +2511,11 @@ var RestoreSettingsDialog = (new function($)
 		$SectionTable.fasttable(
 			{
 				pagerContainer: $('#RestoreSettingsDialog_SectionTable_pager'),
-				headerCheck: $('#RestoreSettingsDialog_SectionTable > thead > tr:first-child'),
+				rowSelect: UISettings.rowSelect,
 				infoEmpty: 'No sections found.',
 				pageSize: 1000
 			});
 
-		$SectionTable.on('click', 'tbody div.check',
-			function(event) { $SectionTable.fasttable('itemCheckClick', this.parentNode.parentNode, event); });
-		$SectionTable.on('click', 'thead div.check',
-			function() { $SectionTable.fasttable('titleCheckClick') });
-		$SectionTable.on('mousedown', Util.disableShiftMouseDown);
-
 		$RestoreSettingsDialog.on('hidden', function()
 		{
 			// cleanup
@@ -2556,7 +2564,7 @@ var RestoreSettingsDialog = (new function($)
 		var checkedCount = $SectionTable.fasttable('checkedCount');
 		if (checkedCount === 0)
 		{
-			Notification.show('#Notif_Config_RestoreSections');
+			PopupNotification.show('#Notif_Config_RestoreSections');
 			return;
 		}
 
@@ -2579,7 +2587,7 @@ var UpdateDialog = (new function($)
 	var $UpdateDialog;
 	var $UpdateProgressDialog;
 	var $UpdateProgressDialog_Log;
-	
+
 	// State
 	var VersionInfo;
 	var PackageInfo;
@@ -2606,7 +2614,7 @@ var UpdateDialog = (new function($)
 			Refresher.resume();
 		}
 	}
-	
+
 	this.showModal = function()
 	{
 		$('#UpdateDialog_Install').hide();
@@ -2619,7 +2627,7 @@ var UpdateDialog = (new function($)
 		$('#UpdateDialog_InstalledInfo').show();
 
 		$('#UpdateDialog_VerInstalled').text(Options.option('Version'));
-		
+
 		PackageInfo = {};
 		VersionInfo = {};
 		UpdateInfo = {};
@@ -2631,7 +2639,7 @@ var UpdateDialog = (new function($)
 
 		RPC.call('readurl', ['http://nzbget.net/info/nzbget-version.json?nocache=' + new Date().getTime(), 'version info'], loadedUpstreamInfo, error);
 	}
-	
+
 	function error(e)
 	{
 		$('#UpdateDialog_CheckProgress').hide();
@@ -2644,7 +2652,7 @@ var UpdateDialog = (new function($)
 		var obj = JSON.parse(jsonp.substr(p, 10000));
 		return obj;
 	}
-	
+
 	function loadedUpstreamInfo(data)
 	{
 		VersionInfo = parseJsonP(data);
@@ -2661,10 +2669,10 @@ var UpdateDialog = (new function($)
 	function loadGitVerData()
 	{
 		// fetching devel version number from svn viewer
-		RPC.call('readurl', ['https://github.com/nzbget/nzbget', 'git revision info'], 
+		RPC.call('readurl', ['https://github.com/nzbget/nzbget', 'git revision info'],
 			function(gitRevData)
 			{
-				RPC.call('readurl', ['https://raw.githubusercontent.com/nzbget/nzbget/develop/configure.ac', 'git branch info'], 
+				RPC.call('readurl', ['https://raw.githubusercontent.com/nzbget/nzbget/develop/configure.ac', 'git branch info'],
 					function(gitBranchData)
 					{
 						var html = document.createElement('DIV');
@@ -2672,7 +2680,7 @@ var UpdateDialog = (new function($)
 						html = html.textContent || html.innerText || '';
 						html = html.replace(/(?:\r\n|\r|\n)/g, ' ');
 						var rev = html.match(/([0-9\,]*)\s*commits/);
-   
+
 						if (rev && rev.length > 1)
 						{
 							rev = rev[1].replace(',', '');
@@ -2682,17 +2690,17 @@ var UpdateDialog = (new function($)
 								VersionInfo['devel-version'] = ver[1] + '-r' + rev;
 							}
 						}
-						
+
 						loadPackageInfo();
 					}, error);
 			}, error);
 	}
-	
+
 	function loadPackageInfo()
 	{
 		$.get('package-info.json', loadedPackageInfo, 'html').fail(loadedAll);
 	}
-	
+
 	function loadedPackageInfo(data)
 	{
 		PackageInfo = parseJsonP(data);
@@ -2715,12 +2723,12 @@ var UpdateDialog = (new function($)
 		UpdateInfo = parseJsonP(data);
 		loadedAll();
 	}
-	
+
 	function formatTesting(str)
 	{
 		return str.replace('-testing-', '-');
 	}
-	
+
 	function revision(version)
 	{
 		var rev = version.match(/.*r(\d+)/);
@@ -2732,7 +2740,7 @@ var UpdateDialog = (new function($)
 		var ver = version.match(/([\d.]+).*/);
 		return ver && ver.length > 1 ? parseFloat(ver[1]) : 0;
 	}
-	
+
 	function loadedAll()
 	{
 		var installedVersion = Options.option('Version');
@@ -2751,7 +2759,7 @@ var UpdateDialog = (new function($)
 		Util.show('#UpdateDialog_CurNotesStable', VersionInfo['stable-release-notes']);
 		Util.show('#UpdateDialog_CurNotesTesting', VersionInfo['testing-release-notes']);
 		Util.show('#UpdateDialog_CurNotesDevel', VersionInfo['devel-release-notes']);
-	
+
 		$('#UpdateDialog_AvailStable').text(UpdateInfo['stable-version'] ? UpdateInfo['stable-version'] : 'not available');
 		$('#UpdateDialog_AvailTesting').text(UpdateInfo['testing-version'] ? formatTesting(UpdateInfo['testing-version']) : 'not available');
 		$('#UpdateDialog_AvailDevel').text(UpdateInfo['devel-version'] ? formatTesting(UpdateInfo['devel-version']) : 'not available');
@@ -2766,20 +2774,20 @@ var UpdateDialog = (new function($)
 		var installedRev = revision(installedVersion);
 		var installedVer = vernumber(installedVersion);
 		var installedStable = installedRev === 0 && installedVersion.indexOf('testing') === -1;
-		
-		var canInstallStable = UpdateInfo['stable-version'] && 
-			((installedStable && installedVer < vernumber(UpdateInfo['stable-version'])) || 
+
+		var canInstallStable = UpdateInfo['stable-version'] &&
+			((installedStable && installedVer < vernumber(UpdateInfo['stable-version'])) ||
 			 (!installedStable && installedVer <= vernumber(UpdateInfo['stable-version'])));
-		var canInstallTesting = UpdateInfo['testing-version'] && 
-			((installedStable && installedVer < vernumber(UpdateInfo['testing-version'])) || 
+		var canInstallTesting = UpdateInfo['testing-version'] &&
+			((installedStable && installedVer < vernumber(UpdateInfo['testing-version'])) ||
 			 (!installedStable && (installedRev === 0 || installedRev < revision(UpdateInfo['testing-version']))));
-		var canInstallDevel = UpdateInfo['devel-version'] && 
-			((installedStable && installedVer < vernumber(UpdateInfo['devel-version'])) || 
+		var canInstallDevel = UpdateInfo['devel-version'] &&
+			((installedStable && installedVer < vernumber(UpdateInfo['devel-version'])) ||
 			 (!installedStable && (installedRev === 0 || installedRev < revision(UpdateInfo['devel-version']))));
 		Util.show('#UpdateDialog_InstallStable', canInstallStable);
 		Util.show('#UpdateDialog_InstallTesting', canInstallTesting);
 		Util.show('#UpdateDialog_InstallDevel', canInstallDevel);
-		
+
 		var hasUpdateSource = PackageInfo['update-info-link'] || PackageInfo['update-info-script'];
 		var hasUpdateInfo = UpdateInfo['stable-version'] || UpdateInfo['testing-version'] || UpdateInfo['devel-version'];
 		var canUpdate = canInstallStable || canInstallTesting || canInstallDevel;
@@ -2789,14 +2797,14 @@ var UpdateDialog = (new function($)
 		Util.show('#UpdateDialog_CheckFailed', hasUpdateSource && !hasUpdateInfo);
 		$('#UpdateDialog_AvailRow').toggleClass('hide', !hasUpdateInfo);
 	}
-	
+
 	function install(e)
 	{
 		e.preventDefault();
 		var kind = $(this).attr('data-kind');
 		var script = PackageInfo['install-script'];
 		var info = PackageInfo['install-' + kind + '-info'];
-		
+
 		if (!script)
 		{
 			alert('Something is wrong with the package configuration file "package-info.json".');
@@ -2809,12 +2817,12 @@ var UpdateDialog = (new function($)
 				RPC.call('startupdate', [kind], updateStarted);
 			});
 	}
-	
+
 	function updateStarted(started)
 	{
 		if (!started)
 		{
-			Notification.show('#Notif_StartUpdate_Failed');
+			PopupNotification.show('#Notif_StartUpdate_Failed');
 			return;
 		}
 
@@ -2830,7 +2838,7 @@ var UpdateDialog = (new function($)
 					});
 			});
 	}
-	
+
 	function updateLog()
 	{
 		RPC.call('logupdate', [0, 100], function(data)
@@ -2864,7 +2872,7 @@ var UpdateDialog = (new function($)
 			$UpdateProgressDialog_Log.scrollTop($UpdateProgressDialog_Log.prop('scrollHeight'));
 		}
 	}
-	
+
 	function updateLogTable(messages)
 	{
 		var html = '';
@@ -2880,7 +2888,7 @@ var UpdateDialog = (new function($)
 		}
 		setLogContentAndScroll(html);
 	}
-	
+
 	function checkStatus()
 	{
 		RPC.call('status', [], function(status)
@@ -2914,5 +2922,5 @@ var UpdateDialog = (new function($)
 				}
 			});
 	}
-	
+
 }(jQuery));
